@@ -1,6 +1,6 @@
 package BioX::Workflow::Plugin::Drake;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 use Data::Dumper;
 use Data::Pairs;
 
@@ -324,10 +324,6 @@ before 'write_process' => sub{
     #Make the formatting a big prettier
     my @tmp = split("\n", $self->process);
     $self->process(join("\n\t", @tmp));
-};
-
-before 'process_template' => sub {
-    my $self = shift;
 
     my $tmp = "{\$self->OUTPUT} <- {\$self->INPUT}\n\t";
     $DB::single=2;
@@ -336,9 +332,21 @@ before 'process_template' => sub {
     }
     my $newprocess = $tmp.$self->process;
     $self->process($newprocess);
-
 };
 
+#before 'process_template' => sub {
+    #my $self = shift;
+
+    #my $tmp = "{\$self->OUTPUT} <- {\$self->INPUT}\n\t";
+    #$DB::single=2;
+    #if($self->min){
+        #$tmp =~ s/\$SAMPLE/\$[SAMPLE]/g;
+    #}
+    #my $newprocess = $tmp.$self->process;
+    #$self->process($newprocess);
+
+#};
+
 1;
 __END__
 
